@@ -12,7 +12,7 @@ class JSONEditorWidget {
         options.onChange = function () {
             var json = editor.get();
             textarea.value=JSON.stringify(json);
-        }        
+        }
         const editor = new JSONEditor(element, options);
         editor.set(JSON.parse(textarea.value));
     }
@@ -23,12 +23,18 @@ document.addEventListener('DOMContentLoaded', function() {
 });
 
 function createJSONFieldEditors() {
-    const els = document.getElementsByClassName('json_editor_widget');
+
+    const els = document.getElementsByClassName('w-field--json_editor_widget');
     for (const el of els) {
-        const collection = el.getElementsByClassName('input')
+        const collection = el.getElementsByClassName('w-field__input')
         if (collection.length === 0) {
             continue;
         }
-        new JSONEditorWidget(collection[0]);
+
+        // So we don't duplicate editor widgets if we have JSONBlock in streamfields
+        // and model field elements on the same page.
+        if (collection[0].firstElementChild.nodeName.toUpperCase() == 'TEXTAREA') {
+            new JSONEditorWidget(collection[0]);
+        }
     }
 }
\ No newline at end of file
